@@ -1,12 +1,19 @@
-RVineSim<-function(N,RVM)
-{	
-  if(!is(RVM, "RVineMatrix")) stop("'RVM' has to be an RVineMatrix object.")
-  
+RVineSim <- function(N, RVM, U=NULL)
+{
+    stopifnot(N >= 1)
+    if(!is(RVM, "RVineMatrix")) stop("'RVM' has to be an RVineMatrix object.")
+
 	n = dim(RVM)
-	
+
 	o = diag(RVM$Matrix)
 	RVM = normalizeRVineMatrix(RVM)
 
+        takeU <- !is.null(U)
+        if(takeU) {
+            if(!is.matrix(U)) U <- rbind(U, deparse.level=0L)
+            if((d <- ncol(U)) < 2) stop("U should be at least bivariate") # should be an (N, n) matrix
+        }
+
 	matri=as.vector(RVM$Matrix)
 	w1=as.vector(RVM$family)
 	th=as.vector(RVM$par)
@@ -32,24 +39,26 @@ RVineSim<-function(N,RVM)
 		as.double(th),
 		as.double(th2),
 		as.double(tmp),
+                as.double(U),
+                as.integer(takeU),
 		PACKAGE = 'VineCopula')[[9]]
 
 	out=matrix(tmp,ncol=n)
 
 
 	if(!is.null(RVM$names)){
-		colnames(out) = RVM$names		
+		colnames(out) = RVM$names
 	}
 
   out = out[,sort(o[length(o):1],index.return=TRUE)$ix]
   return(out)
-}		
+}
 
 
 transform<-function(M)
 {
   n=dim(M)[1]
-  
+
   M.new=matrix(rep(0,n*n),n,n)
   for(i in 1:n)
   {
