@@ -105,8 +105,13 @@ gof_PIT<-function(data,RVM,weight="Breymann",B=200, statisticName="AD", alpha=2)
 		{
 			S[i]=sum(tmp[i,])
 		}
-		if(statisticName==1 && method==1)		# Macht nur Sinn bei Breymann
-			pvalue=ad.test(S,pchisq,df=d)$p.value
+		if(statisticName==1 && method==1){		# Macht nur Sinn bei Breymann
+		  if(requireNamespace("ADGofTest", quietly = TRUE)) {
+		    pvalue=ADGofTest::ad.test(S,pchisq,df=d)$p.value
+		  } else {
+		    stop("For Anderson-Darling 'statistic' the package 'ADGofTest' has to be installed")
+		  }
+		}
 		else if(statisticName==2 && method==1)
 			pvalue=ks.test(S,"pchisq",df=d)$p.value
 		else 
