@@ -41,7 +41,7 @@ void diff2PDF_mod(double* u, double* v, int* n, double* param, int* copula, doub
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -56,7 +56,7 @@ if((*copula==43))
 			diffPDF(u, negv, n, nparam, &ncopula, out2);
 			for(i=0;i<*n;i++){out[i]=out[i]*4/pow(1+param[0],4)+out2[i]*4/pow(1+param[0],3);}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -72,21 +72,21 @@ if((*copula==43))
 			for(i=0;i<*n;i++){out[i]=out[i]/pow(1+param[0],4)+out2[i]*2/pow(1+param[0],3);}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF(u, negv, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF(negu, v, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -341,7 +341,7 @@ void diff2PDF_u_mod(double* u, double* v, int* n, double* param, int* copula, do
   nparam[1]=-param[1];
   int i;
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -353,7 +353,7 @@ if((*copula==43))
 			diff2PDF_u(u, negv, n, nparam, &ncopula, out);
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -366,21 +366,21 @@ if((*copula==43))
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF_u(u, negv, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF_u(negu, v, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -416,7 +416,7 @@ void diff2PDF_v_mod(double* u, double* v, int* n, double* param, int* copula, do
   nparam[1]=-param[1];
   int i;
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -428,7 +428,7 @@ if((*copula==43))
 			diff2PDF_u(negv, u, n, nparam, &ncopula, out);
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -441,21 +441,21 @@ if((*copula==43))
 			//for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF_u(negv, u, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF_u(v, negu, n, nparam, &ncopula, out);
 	  //for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -698,7 +698,7 @@ void diff2PDF_u_v_mod(double* u, double* v, int* n, double* param, int* copula,
   nparam[1]=-param[1];
   int i;
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -710,7 +710,7 @@ if((*copula==43))
 			diff2PDF_u_v(u, negv, n, nparam, &ncopula, out);
 			for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -723,21 +723,21 @@ if((*copula==43))
 			for(i=0;i<*n;i++){out[i]=-out[i];}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF_u_v(u, negv, n, nparam, &ncopula, out);
 	  for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF_u_v(negu, v, n, nparam, &ncopula, out);
 	  for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -974,7 +974,7 @@ void diff2PDF_par_u_mod(double* u, double* v, int* n, double* param, int* copula
   nparam[1]=-param[1];
   int i;
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -987,7 +987,7 @@ if((*copula==43))
 			diff2PDF_par_u(u, negv, n, nparam, &ncopula, out);
 			for(i=0;i<*n;i++){out[i]=-out[i]*2/pow(1+param[0],2);}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -1001,21 +1001,21 @@ if((*copula==43))
 			for(i=0;i<*n;i++){out[i]=-out[i]/pow(1+param[0],2);}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF_par_u(u, negv, n, nparam, &ncopula, out);
 	  for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF_par_u(negu, v, n, nparam, &ncopula, out);
 	  for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
@@ -1278,7 +1278,7 @@ void diff2PDF_par_v_mod(double* u, double* v, int* n, double* param, int* copula
   nparam[0]=-param[0];
   nparam[1]=-param[1];
 
-if((*copula==43))
+if((*copula)==43)
 	{
 		ncopula=3;
 		if(param[0] > 0){
@@ -1291,7 +1291,7 @@ if((*copula==43))
 			diff2PDF_par_u(negv, u, n, nparam, &ncopula, out);
 			for(i=0;i<*n;i++){out[i]=out[i]*2/pow(1+param[0],2);}
 		}
-	}else if((*copula==44))
+	}else if((*copula)==44)
 	{
 		ncopula=4;
 		if(param[0] > 0){
@@ -1305,20 +1305,20 @@ if((*copula==43))
 			for(i=0;i<*n;i++){out[i]=out[i]/pow(1-param[0],2);}
 		}
 	}else{
-  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90 rotated copulas
+  if(((*copula==23) | (*copula==24) | (*copula==26) | (*copula==27) | (*copula==28) | (*copula==29) | (*copula==30)))	// 90? rotated copulas
     {
 	  ncopula = (*copula)-20;
       for (i = 0; i < *n; ++i) {negv[i] = 1 - v[i];}
 	  diff2PDF_par_u(negv, u, n, nparam, &ncopula, out);
     }
-  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270 rotated copulas
+  else if(((*copula==33) | (*copula==34) | (*copula==36) | (*copula==37) | (*copula==38) | (*copula==39) | (*copula==40)))	// 270? rotated copulas
     {
 	  ncopula = (*copula)-30;
       for (i = 0; i < *n; ++i) {negu[i] = 1 - u[i];}
 	  diff2PDF_par_u(v, negu, n, nparam, &ncopula, out);
 	  for(i=0;i<*n;i++){out[i]=-out[i];}
     }
-  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180 rotated copulas
+  else if(((*copula==13) | (*copula==14) | (*copula==16) | (*copula==17) | (*copula==18) | (*copula==19) | (*copula==20)))	// 180? rotated copulas
 	{
 		ncopula = (*copula)-10;
 		for (i = 0; i < *n; ++i) 
